package backend

import (
	"cron_admin/app/http/entities"
	"cron_admin/app/models/cronreportchannelmodel"
	"cron_admin/app/utils"
	"time"
)

type ReportChannelListRequest struct {
	entities.PageRequest
	ReportChannelId int    `json:"report_channel_id" form:"report_channel_id" validate:"min=0"`
	Status          int    `json:"status" form:"status"`
	ClientKey       string `json:"client_key" form:"client_key"`
	//ClientSecret    string   `json:"client_secret" form:"client_secret"`
	CreateTime  []string `json:"create_time" form:"create_time"`
	UpdateTime  []string `json:"update_time" form:"update_time"`
	ChannelName string   `json:"channel_name"  form:"channel_name"`
}

type ReportChannelList struct {
	entities.PageRequest
	ReportChannelId int    `json:"report_channel_id" form:"report_channel_id" validate:"min=0"`
	Status          int    `json:"status" form:"status"`
	ChannelName     string `json:"channel_name"  form:"channel_name"`
	ClientKey       string `json:"client_key" form:"client_key"`
	//ClientSecret    string      `json:"client_secret" form:"client_secret"`
	CreateTime []time.Time `json:"create_time" form:"create_time"`
	UpdateTime []time.Time `json:"update_time" form:"update_time"`
}

func (this *ReportChannelListRequest) Request2DB() (filter ReportChannelList, err error) {
	filter.PageRequest = this.PageRequest
	filter.ReportChannelId = this.ReportChannelId
	filter.ClientKey = this.ClientKey
	filter.ChannelName = this.ChannelName
	//filter.ClientSecret = this.ClientSecret
	filter.Status = this.Status
	filter.CreateTime = []time.Time{}
	var t time.Time
	if len(this.CreateTime) == 2 {
		t, err = utils.StrToTimeShanghai(this.CreateTime[0])
		filter.CreateTime = append(filter.CreateTime, t)
		t, err = utils.StrToTimeShanghai(this.CreateTime[1])
		filter.CreateTime = append(filter.CreateTime, t)
		if err != nil {
			return
		}
	}
	filter.UpdateTime = []time.Time{}
	if len(this.UpdateTime) == 2 {
		t, err = utils.StrToTimeShanghai(this.UpdateTime[0])
		filter.UpdateTime = append(filter.UpdateTime, t)
		t, err = utils.StrToTimeShanghai(this.UpdateTime[1])
		filter.UpdateTime = append(filter.UpdateTime, t)
		if err != nil {
			return
		}
	}
	return
}

type ReportChannelListResponse struct {
	ReportChannelId int    `json:"report_channel_id"`
	ChannelName     string `json:"channel_name"`
	ClientKey       string `json:"client_key"`
	//ClientSecret    string `json:"client_secret"`
	Config     string `json:"config"`
	CreateTime string `json:"create_time"`
	Status     int    `json:"status"`
	UpdateTime string `json:"update_time"`
}

func (this *ReportChannelListResponse) FromDb(in cronreportchannelmodel.CronReportChannel) {
	this.ReportChannelId = in.ReportChannelId
	this.ClientKey = in.ClientKey
	this.ChannelName = in.ChannelName
	this.Config = in.Config
	this.CreateTime = in.CreateTime.Format("2006-01-02 15:04:05")
	this.Status = in.Status
	this.UpdateTime = in.UpdateTime.Format("2006-01-02 15:04:05")
}

type ReportChannelCreateRequest struct {
	ChannelName  string `json:"channel_name" validate:"required" label:"名称"`
	ClientKey    string `json:"client_key" validate:"required" label:"服务key"`
	ClientSecret string `json:"client_secret" validate:"required" label:"服务secret"`
	Config       string `json:"config" validate:"required" label:"服务配置"`
	Status       int    `json:"status" validate:"required" label:"状态"`
}

func (this *ReportChannelCreateRequest) Request2DB() (db cronreportchannelmodel.CronReportChannel) {
	db.ChannelName = this.ChannelName
	db.ClientKey = this.ClientKey
	db.ClientSecret = this.ClientSecret
	db.Config = this.Config
	db.Status = this.Status
	return db
}

type ReportChannelUpdateRequest struct {
	ReportChannelId int    `json:"report_channel_id"  validate:"required" `
	ChannelName     string `json:"channel_name"  label:"名称"`
	ClientKey       string `json:"client_key" label:"配置key"`
	ClientSecret    string `json:"client_secret"  label:"配置密钥"`
	Config          string `json:"config"  label:"配置"`
	Status          int    `json:"status"  label:"状态"`
}

func (this *ReportChannelUpdateRequest) Request2DB() (db cronreportchannelmodel.CronReportChannel) {
	db.ReportChannelId = this.ReportChannelId
	db.ClientKey = this.ClientKey
	db.ChannelName = this.ChannelName
	db.ClientSecret = this.ClientSecret
	db.Config = this.Config
	db.Status = this.Status
	return db
}
